@@ -29,8 +29,7 @@ GMAIL_ARGS = {
 
 class ServicesTest(unittest.TestCase):
   def test_valid_service(self):
-    self.assertGreater(services.Service.DOUBLECLICKSEARCH.value, 0)
+    self.assertGreater(services.Service.CHAT.value, 0)
 
   def test_single_definition(self):
     self.assertEqual(SA360_DEFINITION, services.Service.DOUBLECLICKSEARCH.definition)
-
